# Influx Data Manager

[![PyPI version](https://badge.fury.io/py/influx-si-data-manager.svg)](https://badge.fury.io/py/influx-si-data-manager)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/influx-si-data-manager.svg)](https://pypi.python.org/pypi/influx-si-data-manager/)


## What is the Influx Data Manager?
** IDM (Influx Data Manager) is a python command-line interface tool for ensuring interoperability of tools in fluxomics workflows on the [Workflow4Metabolomics](usegalaxy.workflow4metabolomics.org) galaxy instance.**

It accepts multiple inputs and prepares zip archives to pass to the [influx_si software](influx_si.readthedocs.io).
